@@ -5,7 +5,7 @@
  * This file defines Mnemo's external API interface.  Other applications can
  * interact with Mnemo through this API.
  *
- * Copyright 2001-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2001-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL). If you
  * did not receive this file, see http://www.horde.org/licenses/apache.
@@ -13,9 +13,17 @@
  * @category Horde
  * @package  Mnemo
  */
-
 class Mnemo_Api extends Horde_Registry_Api
 {
+    /**
+     * Links.
+     *
+     * @var array
+     */
+    protected $_links = array(
+        'show' => '%application%/view.php?memo=|memo|&memolist=|memolist|&uid=|uid|'
+    );
+
     /**
      * Removes user data.
      *
@@ -297,7 +305,7 @@ class Mnemo_Api extends Horde_Registry_Api
             } else {
                 $body = $content->body->data;
             }
-            $noteId = $storage->add($content->subject, $body, $content->categories);
+            $noteId = $storage->add(Horde_String::substr($content->subject, 0, 255), $body, $content->categories);
             break;
 
         default:
@@ -438,7 +446,13 @@ class Mnemo_Api extends Horde_Registry_Api
             break;
 
         case 'activesync':
-            $storage->modify($memo['memo_id'], $content->subject, $content->body->data, $content->categories);
+            // We only support plaintext
+            if ($content->body->type == Horde_ActiveSync::BODYPREF_TYPE_HTML) {
+                $body = Horde_Text_Filter::filter($content->body->data, 'Html2text');
+            } else {
+                $body = $content->body->data;
+            }
+            $storage->modify($memo['memo_id'], Horde_String::substr($content->subject, 0, 255), $body, $content->categories);
             break;
 
         default:
@@ -496,7 +510,7 @@ class Mnemo_Api extends Horde_Registry_Api
      * @return string  The new notepad's id.
      * @since 4.2.0
      */
-    public function addNotpad($name, array $params = array())
+    public function addNotepad($name, array $params = array())
     {
         if ($GLOBALS['prefs']->isLocked('default_notepad')) {
             throw new Horde_Exception_PermissionDenied();
