@@ -5,7 +5,7 @@
  * This file defines Horde's core API interface. Other core Horde libraries
  * can interact with Mnemo through this API.
  *
- * Copyright 2010-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2010-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL). If you
  * did not receive this file, see http://www.horde.org/licenses/apache.
@@ -43,7 +43,7 @@ class Mnemo_Application extends Horde_Registry_Application
 
     /**
      */
-    public $version = 'H5 (4.2.1)';
+    public $version = 'H5 (4.2.7)';
 
     /**
      * Global variables defined:
@@ -178,6 +178,8 @@ class Mnemo_Application extends Horde_Registry_Application
     public function topbarCreate(Horde_Tree_Renderer_Base $tree, $parent = null,
                                  array $params = array())
     {
+        global $registry;
+
         $add = Horde::url('memo.php', true)->add('actionID', 'add_memo');
 
         $tree->addNode(array(
@@ -191,7 +193,11 @@ class Mnemo_Application extends Horde_Registry_Application
             )
         ));
 
-        foreach (Mnemo::listNotepads(false, Horde_Perms::EDIT) as $name => $notepad) {
+        $user = $registry->getAuth();
+        foreach (Mnemo::listNotepads(false, Horde_Perms::SHOW) as $name => $notepad) {
+            if (!$notepad->hasPermission($user, Horde_Perms::EDIT)) {
+                continue;
+            }
             $tree->addNode(array(
                 'id' => $parent . $name . '__new',
                 'parent' => $parent . '__new',
