@@ -2,7 +2,7 @@
 /**
  * Horde Mnemo driver for the Kolab_Storage backend.
  *
- * Copyright 2004-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2004-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL). If you
  * did not receive this file, see http://www.horde.org/licenses/apache.
@@ -337,7 +337,7 @@ class Mnemo_Driver_Kolab extends Mnemo_Driver
                 $tagger->replaceTags(
                     $note['uid'],
                     $note['categories'],
-                    $this->_notepad,
+                    $GLOBALS['registry']->getAuth(),
                     'note'
                 );
             }
