@@ -2,7 +2,7 @@
 /**
  * Horde_Injector factory to create Mnemo_Driver instances.
  *
- * Copyright 2011-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2011-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL). If you
  * did not receive this file, see http://www.horde.org/licenses/apache.
@@ -56,11 +56,13 @@ class Mnemo_Factory_Driver
 
             switch ($class) {
             case 'Mnemo_Driver_Sql':
-                $params = array(
-                    'db' => $this->_injector->getInstance('Horde_Db_Adapter'),
-                    'table' => 'mnemo_memos',
-                    'charset' => $params['charset'],
-                );
+                if ($params['driverconfig'] != 'horde') {
+                    $customParams = $params;
+                    unset($customParams['driverconfig'], $customParams['table']);
+                    $params['db'] = $this->_injector->getInstance('Horde_Core_Factory_Db')->create('mnemo', $customParams);
+                } else {
+                    $params['db'] = $this->_injector->getInstance('Horde_Db_Adapter');
+                }
                 break;
 
             case 'Mnemo_Driver_Kolab':
