@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2001-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2001-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL). If you
  * did not receive this file, see http://www.horde.org/licenses/apache.
@@ -50,8 +50,21 @@ function showPassphrase($memo)
     return false;
 }
 
+function getShare($notepad)
+{
+    global $mnemo_shares, $notification;
+
+    try {
+        return $mnemo_shares->getShare($notepad);
+    } catch (Horde_Share_Exception $e) {
+        $notification->push(sprintf(_("There was an error viewing this notepad: %s"), $e->getMessage()), 'horde.error');
+        Horde::url('list.php', true)->redirect();
+    }
+}
+
 require_once __DIR__ . '/lib/Application.php';
 Horde_Registry::appInit('mnemo');
+$user = $registry->getAuth();
 
 /* Redirect to the notepad view if no action has been requested. */
 $memo_id = Horde_Util::getFormData('memo');
@@ -81,28 +94,28 @@ case 'add_memo':
             $memolist_id = Mnemo::getDefaultNotepad();
         } catch (Mnemo_Exception $e) {
             $notification->push($e);
+            Horde::url('list.php', true)->redirect();
         }
     }
-    try {
-        $share = $mnemo_shares->getShare($memolist_id);
-    } catch (Horde_Share_Exception $e) {
-        $notification->push($e);
-        Horde::url('list.php', true)->redirect();
-    }
-    if (!$share->hasPermission($registry->getAuth(), Horde_Perms::EDIT)) {
+    if (!getShare($memolist_id)->hasPermission($user, Horde_Perms::EDIT)) {
         $notification->push(_("Access denied addings notes to this notepad."), 'horde.error');
         Horde::url('list.php', true)->redirect();
     }
     $memo_id = null;
     $memo_body = '';
     $memo_encrypted = $show_passphrase = false;
-    $storage = $GLOBALS['injector']->getInstance('Mnemo_Factory_Driver')->create();
+    $storage = $injector->getInstance('Mnemo_Factory_Driver')->create();
     $memo_tags = array();
 
     $title = _("New Note");
     break;
 
 case 'modify_memo':
+    if (!getShare($memolist_id)->hasPermission($user, Horde_Perms::EDIT)) {
+        $notification->push(_("Access denied editing note."), 'horde.error');
+        Horde::url('list.php', true)->redirect();
+    }
+
     /* Check if a passphrase has been sent. */
     $passphrase = Horde_Util::getFormData('memo_passphrase');
 
@@ -113,7 +126,8 @@ case 'modify_memo':
         $notification->push(_("Note not found."), 'horde.error');
         Horde::url('list.php', true)->redirect();
     }
-    $storage = $GLOBALS['injector']->getInstance('Mnemo_Factory_Driver')->create($memolist_id);
+    $storage = $injector->getInstance('Mnemo_Factory_Driver')
+        ->create($memolist_id);
 
     /* Encryption tests. */
     $show_passphrase = showPassphrase($memo);
@@ -138,15 +152,11 @@ case 'save_memo':
     // Save the memolist in case saving fails Bug: 12855
     $memolist_id = $notepad_target;
 
-    try {
-        $share = $mnemo_shares->getShare($notepad_target);
-    } catch (Horde_Share_Exception $e) {
-        $notification->push($e);
-        Horde::url('list.php', true)->redirect();
-    }
-
-    if (!$share->hasPermission($registry->getAuth(), Horde_Perms::EDIT)) {
-        $notification->push(_("Access denied saving note to this notepad."), 'horde.error');
+    if (!getShare($notepad_target)->hasPermission($user, Horde_Perms::EDIT)) {
+        $notification->push(
+            _("Access denied saving note to this notepad."),
+            'horde.error'
+        );
     } elseif ($memo_passphrase != $memo_passphrase2) {
         $notification->push(_("The passwords don't match."), 'horde.error');
         if (empty($memo_id)) {
@@ -163,38 +173,28 @@ case 'save_memo':
             $memo_encrypted = $memo['encrypted'];
             $memolist_id = $memolist_original;
         }
-        $storage = $GLOBALS['injector']->getInstance('Mnemo_Factory_Driver')->create($memolist_original);
+        $storage = $injector->getInstance('Mnemo_Factory_Driver')
+            ->create($memolist_original);
         break;
     } else {
         /* If $memo_id is set, we're modifying an existing note.  Otherwise,
          * we're adding a new note with the provided attributes. */
         if (!empty($memo_id)) {
-            $storage = $GLOBALS['injector']->getInstance('Mnemo_Factory_Driver')->create($memolist_original);
+            $storage = $injector->getInstance('Mnemo_Factory_Driver')
+                ->create($memolist_original);
             if ($memolist_original != $notepad_target) {
                 /* Moving the note to another notepad. */
-                try {
-                    $share = $mnemo_shares->getShare($memolist_original);
-                } catch (Horde_Share_Exception $e) {
-                    throw new Mnemo_Exception($e);
-                }
-                if ($share->hasPermission($registry->getAuth(), Horde_Perms::DELETE)) {
-                    try {
-                        $share = $mnemo_shares->getShare($notepad_target);
-                    } catch (Horde_Share_Exception $e) {
-                        throw new Mnemo_Exception($e);
-                    }
-                    if ($share->hasPermission($registry->getAuth(), Horde_Perms::EDIT)) {
-                        $storage->move($memo_id, $notepad_target);
-                        $storage = $GLOBALS['injector']->getInstance('Mnemo_Factory_Driver')->create($notepad_target);
-                    } else {
-                        $notification->push(_("Access denied moving the note."), 'horde.error');
-                    }
-                } else {
+                if (!getShare($memolist_original)->hasPermission($user, Horde_Perms::DELETE)) {
                     $notification->push(_("Access denied moving the note."), 'horde.error');
+                } else {
+                    $storage->move($memo_id, $notepad_target);
+                    $storage = $injector->getInstance('Mnemo_Factory_Driver')
+                        ->create($notepad_target);
                 }
             }
             $memo_desc = $storage->getMemoDescription($memo_body);
-            if (!strlen($memo_passphrase) && Horde_Util::getFormData('memo_encrypt') == 'on') {
+            if (!strlen($memo_passphrase) &&
+                Horde_Util::getFormData('memo_encrypt') == 'on') {
                 $memo_passphrase = Mnemo::getPassphrase($memo_id);
             }
             try {
@@ -212,7 +212,8 @@ case 'save_memo':
                 Horde::url('list.php', true)->redirect();
             }
             /* Creating a new note. */
-            $storage = $GLOBALS['injector']->getInstance('Mnemo_Factory_Driver')->create($notepad_target);
+            $storage = $injector->getInstance('Mnemo_Factory_Driver')
+                ->create($notepad_target);
             $memo_desc = $storage->getMemoDescription($memo_body);
             try {
                 $memo_id = $storage->add(
@@ -236,17 +237,10 @@ case 'save_memo':
 
 case 'delete_memos':
     /* Delete the note if we're provided with a valid note ID. */
-    $memo_id = Horde_Util::getFormData('memo');
-    $memolist_id = Horde_Util::getFormData('memolist');
-
     if (!is_null($memo_id) && Mnemo::getMemo($memolist_id, $memo_id)) {
-        try {
-            $share = $mnemo_shares->getShare($memolist_id);
-        } catch (Horde_Share_Exception $e) {
-            throw new Mnemo_Exception($e);
-        }
-        if ($share->hasPermission($registry->getAuth(), Horde_Perms::DELETE)) {
-            $storage = $GLOBALS['injector']->getInstance('Mnemo_Factory_Driver')->create($memolist_id);
+        if (getShare($memolist_id)->hasPermission($user, Horde_Perms::DELETE)) {
+            $storage = $injector->getInstance('Mnemo_Factory_Driver')
+                ->create($memolist_id);
             try {
                 $storage->delete($memo_id);
                 $notification->push(_("The note was deleted."), 'horde.success');
@@ -293,7 +287,10 @@ if (!$view->modify || !$view->passphrase) {
     $view->loadingImg = Horde::img('loading.gif', _("Loading..."));
     $view->notepads = array();
     if (!$prefs->isLocked('default_notepad')) {
-        foreach (Mnemo::listNotepads(false, Horde_Perms::EDIT) as $id => $notepad) {
+        foreach (Mnemo::listNotepads(false, Horde_Perms::SHOW) as $id => $notepad) {
+            if (!$notepad->hasPermission($user, Horde_Perms::EDIT)) {
+                continue;
+            }
             $view->notepads[] = array(
                 'id' => $id,
                 'selected' => $id == $memolist_id,
@@ -303,7 +300,7 @@ if (!$view->modify || !$view->passphrase) {
     }
     $view->tags = implode(', ', $memo_tags);
     if ($memo_id &&
-        $mnemo_shares->getShare($memolist_id)->hasPermission($registry->getAuth(), Horde_Perms::DELETE)) {
+        $mnemo_shares->getShare($memolist_id)->hasPermission($user, Horde_Perms::DELETE)) {
         $view->delete = Horde::url('memo.php')->add(array(
             'memo' => $memo_id,
             'memolist' => $memolist_id,
