@@ -2,7 +2,7 @@
 /**
  * Adds tables for the Sqlng share driver.
  *
- * Copyright 2011-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2011-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL). If you
  * did not receive this file, see http://www.horde.org/licenses/apache.
@@ -19,6 +19,10 @@ class MnemoUpgradeSqlng extends Horde_Db_Migration_Base
      */
     public function up()
     {
+        if (in_array('mnemo_sharesng', $this->tables())) {
+            return;
+        }
+
         $t = $this->createTable('mnemo_sharesng', array('autoincrementKey' => 'share_id'));
         $t->column('share_name', 'string', array('limit' => 255, 'null' => false));
         $t->column('share_owner', 'string', array('limit' => 255));
